/******************************* main.c *******************************/
/*
ECE 495C, Spring 2008
Team 10

Prototype using 9S12C32 to control an HP Photosmart R707

*/            

#include <hidef.h> 
#include <mc9s12c32.h>
#pragma LINK_INFO DERIVATIVE "mc9s12c32"

#include "sci.h"
#include "pll.h"
#include "timer.h"
#include "sd.h"
#include "debug.h"

/*
Connections:

PTT0 - On/Off
PTT1 - Auto focus
PTT2 - Shutter

*/

unsigned char SD_Buffer[SD_BLOCK_SIZE];

void main(void) {
   unsigned char keyPress;	
   unsigned short i,j;	
   int prev=0, curr=0;
   
   char *replace = "OMG, h4x0red!!!";
   char *pos;
   										   
   DDRT |= 0xFF;     // PortT bits 0-7 are output
  
   // use PTAD for digital input
   ATDDIEN = 0xFF;
   
     
   // Initialize all subsystems
   SCI_Init(19200);  
   PLL_Init();   
   Timer_Initialize(0,1); 
   
   SD_Init();
   i = SD_Card_Init();
   
   PTT = 0;
   
   DEBUG("Reading block 645\r\n");
   i = SD_Read_Block(SD_Buffer, 645);   
   
   SCI_OutString("Before: ");
   for (i=0; i<30; i++)
   {
      SCI_OutChar(SD_Buffer[i]);
   }
   SCI_OutString("\r\n");
   
   // modify the buffer
   pos = replace;
   i = 6;
   while (*replace) 
   {
      SD_Buffer[i] = *replace;
      replace++;
      i++;
   }  
   
   SCI_OutString("After:  ");
   for (i=0; i<30; i++)
   {
      SCI_OutChar(SD_Buffer[i]);
   }
   SCI_OutString("\r\n");
   
   //for (;;);
      
   
   DEBUG("Writing edited block 645\r\n");    
   i = SD_Write_Block(SD_Buffer, 645);
   
   
   for (j=645; j<1000; j++)
   {	
      i = SD_Read_Block(SD_Buffer, j);
           		      
      SCI_OutString("Contents of memory block ");
      SCI_OutUInt(j);
      SCI_OutString("\r\n");
      
      // print out a hex dump
      for (i=1; i<=SD_BLOCK_SIZE; i++)
      {
         SCI_OutHex(SD_Buffer[i-1]);
         if ( (i%16) == 0 )
            SCI_OutString("\r\n");
         else if ( (i%8) == 0 )
            SCI_OutString("  ");
         else
            SCI_OutChar(' ');
      }
      SCI_OutString("\r\n");
      SCI_OutString("\r\n");
      
      // wait for button press
      for(;;)
      {         
         if (PTAD & 0x80) curr=0; else curr=1;
         if (curr & !prev) break;
         prev = curr;
      }
      
   }
   
   
   // loop forever
   for(;;)
   {    
   /* 
      // Test R707 Camera interface
      
      keyPress = SCI_InChar();
      if (keyPress == 'o' || keyPress == 'O') 
      {
         // strobe On/Off signal
         SCI_OutString("On/Off\r\n");
         
         PTT |= 0x01;
         Timer_Wait1ms(100);
         PTT &= ~0x01;
      }
      else if (keyPress == 'a' || keyPress == 'A') 
      {
         // turn on auto focus signal
         SCI_OutString("Auto focus\r\n");
         
         PTT |= 0x02;         
      }
      else if (keyPress == 's' || keyPress == 'S') 
      {
         // strobe shutter signal
         SCI_OutString("Shutter\r\n");
         
         PTT |= 0x06;   
         Timer_Wait1ms(50);
         PTT &= ~0x06;      
      }
    */
      if (SD_IS_CARD_INSERTED()) 
      {
         PTT |= 0x01;
      }
      else
      {
         PTT &= ~0x01;
      }
      
      
      // end main loop
   }
   
   // end main function
}


