/******************************* sci.c *******************************/

// Functions for use with SCI to perform serial communications
 
#include <mc9s12c32.h>
#include "SCI.h"
#include "constants.h"


char PrintBuffer[PRINT_BUFFER_SIZE];   


// sets the serial port baud rate to anything you like
// taking into account the system clock frequency
void SCI_Init(unsigned long int BaudRate)
{
   BaudRate = (CLOCK_SPEED / 16) / BaudRate;  // determine the frequency divisor
   
   SCIBDH = BaudRate >> 8;                    // set high portion of divisor 
   SCIBDL = BaudRate & 0xFF;                  // set low portion of divisor
   SCICR1 = 0;                                // various transmission settings
   SCICR2 = 0x0C;                             // enable transmit and receive
}
    

// wait for data to fill SCI data register then return it
char SCI_InChar(void)
{
   while (!(SCISR1 & RDRF));
   return SCIDRL;
}

        
// wait for SCI data register to be empty, then fill it with the input value to send it over SCI
void SCI_OutChar(char data)
{
  while (!(SCISR1 & TDRE));
  SCIDRL = data;
}     



// Outputs a null terminated string over SCI
void SCI_OutString(char *pVal)
{
   while(*pVal)
   {
      SCI_OutChar(*pVal);
      pVal++;
   }
}


// Outputs a 16bit unsigned integer (0-65536)
void SCI_OutUInt(unsigned short n)
{	 
   unsigned char i=0;
     
   do
   {
      PrintBuffer[i++] = n % 10;
      n /= 10;   
   } while (n);
   
   do
   { 
      SCI_OutChar(PrintBuffer[--i] + '0');
   } while (i);
}



// Outputs a 32bit unsigned integer
void SCI_OutULInt(unsigned long n)
{	 
   unsigned char i=0;
     
   do
   {
      PrintBuffer[i++] = n % 10;
      n /= 10;   
   } while (n);
   
   do
   { 
      SCI_OutChar(PrintBuffer[--i] + '0');
   } while (i);
}


// Outputs a 16bit unsigned integer
// fit to a certain minimum width
void SCI_OutUIntF(unsigned short n, unsigned char width)
{	 
   unsigned char i=0;
   
   // determine digits  
   do
   {
      PrintBuffer[i++] = n % 10;
      n /= 10;   
   } while (n);
   
   // pad with spaces
   while (width > i)
   {
      SCI_OutChar(' ');
      width--;
   }   
   
   // output digits
   do
   { 
      SCI_OutChar(PrintBuffer[--i] + '0');
   } while (i);
}

// prints a character as hex
void SCI_OutHex(unsigned char data)
{
   unsigned H, L;
   L = data & 0xF;
   H = data >> 4;
  
   if (H > 9)
      SCI_OutChar(H - 10 + 'A');
   else
      SCI_OutChar(H + '0');
    
   if (L > 9)
      SCI_OutChar(L - 10 + 'A');
   else
     SCI_OutChar(L + '0');
}



